//* AUTHOR:  Sarah D Groulx 	LAST MODIFIED:  June 30th, 1998

//*  This is an example of a main program/macro to run ATLFast

//*  This Macro loads a shared library created by the user.
//*  The library fills user variables which are then entered 
//*  into the tree defined in this Macro.

{

//* Reset  root memory and load ATLFAST libraries

   gROOT->Reset();
   gROOT->Macro("$ATLFAST/loadlibs");

//* Open the root output file -- not necessary
//  TFile file("atlfast.root","recreate","ATLFast root file",1);
   
//* Create main object to run atlfast
   ATLFast atlfast("atlfast");     

//* Load user's dynamic library.  This is created with Make.
   gSystem->Load("libUser.so");   



//* Define pointers "userWplus" and "userWminus". This is a member of the
//* User class defined in the libUser.so library

   User *userWplus  = new User();
   User *userWminus = new User();


//* create output file
   hfile = new TFile("htree.root","RECREATE","Demo ROOT file with 
	              working trees");

//* Initialize user routine -- sets Pythia cards.
   userWplus->Init();
   userWminus->Init();


//* Initialise event (maker histograms,etc)
   atlfast.Init();      


//* Create a tree with two branches. Branch is defined as a reference 
//* to the user object. So, anything filled from operations
//* on the user object will appear in the the branches of the tree.
//* See User.h for class definitions.

   tree = new TTree("Tree","Example Tree");

//* Autosave when 1 Gbyte written
   tree->SetAutoSave(1000000000);  
 
//* Create two branches of type user.  This branch is for
//* the W information, but it also contains information on the
//* two W decay products.

   tree->Branch("Wplus_Branch", "User", &userWplus, 16000, 1); 
   tree->Branch("Wminus_Branch", "User", &userWminus, 16000, 1);


//* Create the Root tree -- not necessary
//   atlfast.MakeTree();  


//* Initialize PYTHIA
   TPythia *pythia = (TPythia *)gATLFast->MCMaker()->Generator();


//* Variable for W and Children of W line numbers and KF codes.
//* These are used in the calls to the User routines.
   Int_t W, Child1, Child2;
   Int_t Wplus = 24;
   Int_t Wminus= -24;
   Int_t Parent= 6;  	// Uses absolute value of parent
   Int_t nevents=100;


//* loop over events
   for (Int_t i=0; i<nevents; i++) 
      {
//* Generate and Reconstruct event
      atlfast.Make(i);       
//* Print event listing for first evennt only.
      if (i==0) pythia->LuList(1);

//* Fill user variables. In this case, find the W and W decay
//* particles, and fill this information into tree.  This is
//* done for every event.

      userWplus->GetParticle(Wplus, Parent, W);
      if (userWplus->CurrentParticle()!=NULL)
        userWplus->GetChildren(W, Child1, Child2);
   
      userWminus->GetParticle(Wminus, Parent, W);
      if (userWminus->CurrentParticle()!=NULL)
        userWminus->GetChildren(W, Child1, Child2);

//* Fill the tree this event
        if ((userWplus->CurrentFirstChild()!=NULL)&&
            (userWminus->CurrentFirstChild()!=NULL))
          tree->Fill();

//* Clear reconstructed event lists      
      atlfast.Clear();       
   }

   atlfast.Finish();
//* save objects in Root file -- not necessary
//   atlfast.Write();  //save main atlfast object (and run parameters)


//* Print summary of the tree, then write it out to a file
   tree->Print();
   tree->Write();

//* close file
   hfile->Close();
}



